pub enum CodeLocation {
None,
File {
filename: String,
},
FileTag {
filename: String,
tag: String,
},
StdOut,
}Expand description
Location of the code to be generated or verified
Variants
None
- Generate mode: doesn’t write anything.
- Verify mode: returns
None.
File
- Generate mode: creates a new file or overwrites an existing one.
- Verify mode: reads the expected code from an existing file.
FileTag
- Generate mode: inserts the code between tags into an existing file.
- Verify mode: reads the expected code between tags of an existing file.
StdOut
- Generate mode: writes the code to stdout.
- not a valid option in verify mode
Implementations